summaryrefslogtreecommitdiffstats
path: root/examples/dbus/remotecontrolledcar/car/car_adaptor.h
diff options
context:
space:
mode:
Diffstat (limited to 'examples/dbus/remotecontrolledcar/car/car_adaptor.h')
-rw-r--r--examples/dbus/remotecontrolledcar/car/car_adaptor.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/examples/dbus/remotecontrolledcar/car/car_adaptor.h b/examples/dbus/remotecontrolledcar/car/car_adaptor.h
index 3c2c1dd124..c7542ae811 100644
--- a/examples/dbus/remotecontrolledcar/car/car_adaptor.h
+++ b/examples/dbus/remotecontrolledcar/car/car_adaptor.h
@@ -64,14 +64,14 @@ class QVariant;
QT_END_NAMESPACE
/*
* Adaptor class for interface com.trolltech.Examples.CarInterface
*/
class CarInterfaceAdaptor: public QDBusAbstractAdaptor
{
Q_OBJECT
- Q_CLASSINFO("D-Bus Interface", "com.trolltech.Examples.CarInterface")
+ Q_CLASSINFO("D-Bus Interface", "org.example.Examples.CarInterface")
Q_CLASSINFO("D-Bus Introspection", ""
-" <interface name=\"com.trolltech.Examples.CarInterface\">\n"
+" <interface name=\"org.example.Examples.CarInterface\">\n"
" <method name=\"accelerate\"/>\n"
" <method name=\"decelerate\"/>\n"
" <method name=\"turnLeft\"/>\n"
@@ -64,14 +64,14 @@ class QVariant;
QT_END_NAMESPACE
/*
- * Adaptor class for interface com.trolltech.Examples.CarInterface
+ * Adaptor class for interface org.example.Examples.CarInterface
*/
class CarInterfaceAdaptor: public QDBusAbstractAdaptor